@@ -433,7 +433,12 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             resp['avm'] = y_predd
             resp['avm_lower'] = _confs['avm_lower']
             resp['avm_upper'] = _confs['avm_upper']
-            resp = self._get_bounds(resp, y_predd)
+
+            if _confs['avm_lower'] is not np.nan:
+                resp = self._get_bounds(resp, y_predd)
+            else:
+                resp['conf'] = [np.nan]
+
             resp['ts'] = [ts]
             resp['latest_production_version'] = [latest_production_version]
             resp['latest_staging_version'] = [latest_staging_version]
@@ -452,6 +457,10 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             resp['ts'] = [ts]
             resp['latest_production_version'] = [latest_production_version]
             resp['latest_staging_version'] = [latest_staging_version]
+            self.master_match_keys[match_key] = {
+                'avm_lower': lower,
+                'avm_upper': upper
+            }
             self.l.append(resp)
             return self
 
